@@ -478,6 +478,8 @@ TEST(LasWriterTest, extra_dims)
 
     Options writerOps;
     writerOps.add("extra_dims", "Red=int32, Blue = int16, Green = int32_t");
+    writerOps.add("minor_version", "2");
+    writerOps.add("dataformat_id", "3");
     writerOps.add("filename", Support::temppath("simple.las"));
     LasWriter writer;
     writer.setInput(reader);
@@ -616,6 +618,7 @@ TEST(LasWriterTest, forward)
     Options writerOps;
     writerOps.add("forward", "header");
     writerOps.add("minor_version", 3);
+    writerOps.add("dataformat_id", 3);
     writerOps.add("filename", testfile);
 
     LasWriter w;
@@ -831,6 +834,7 @@ TEST(LasWriterTest, lazperf)
 
     Options writerOps;
     writerOps.add("filename", testfile);
+    writerOps.add("forward", "dataformat_id, minor_version");
     writerOps.add("compression", "lazperf");
 
     LasWriter lazWriter;
@@ -1262,10 +1266,21 @@ TEST(LasWriterTest, pdal_add_vlr)
           "metadata": "software_id"
           })"
     );
+    std::string vlr4(
+      R"({
+          "description": "An explicit EVLR",
+          "record_id": 45,
+          "user_id": "hobu",
+          "evlr": true,
+          "metadata": "software_id"
+          })"
+    );
     Options writerOpts;
     writerOpts.add("vlrs", vlr1);
     writerOpts.add("vlrs", vlr2);
     writerOpts.add("vlrs", vlr3);
+    writerOpts.add("vlrs", vlr4);
+    writerOpts.add("minor_version", 4);
     writerOpts.add("filename", outfile);
 
     LasReader reader;
@@ -1287,7 +1302,7 @@ TEST(LasWriterTest, pdal_add_vlr)
     reader2.execute(t2);
 
     const VlrList& vlrs = reader2.header().vlrs();
-    EXPECT_EQ(vlrs.size(), 3u);
+    EXPECT_EQ(vlrs.size(), 4u);
 
     const LasVLR& v0 = vlrs[0];
     std::string s0(v0.data(), v0.data() + v0.dataLen());
@@ -1300,6 +1315,10 @@ TEST(LasWriterTest, pdal_add_vlr)
     const LasVLR& v2 = vlrs[2];
     std::string s2(v2.data(), v2.data() + v2.dataLen());
     EXPECT_EQ(s2, "TerraScan");
+
+    const LasVLR& v3 = vlrs[3];
+    std::string s3(v3.data(), v3.data() + v3.dataLen());
+    EXPECT_EQ(s3, "TerraScan");
 }
 
 TEST(LasWriterTest, pdal_wkt2_vlr)
@@ -1751,6 +1770,8 @@ TEST(LasWriterTest, oversize_vlr)
     Options o;
 
     o.add("filename", "out.las");
+    o.add("minor_version", "2");
+    o.add("dataformat_id", "3");
     w.addOptions(o);
 
     PointTable t;
@@ -2272,7 +2293,7 @@ TEST(LasWriterTest, issue2235)
         writer41.execute(table41);
 
         const las::Header& h41 = tester.header(writer41);
-        EXPECT_EQ(h41.legacyPointCount, (int32_t)h41.pointCount());
+        EXPECT_EQ(h41.legacyPointCount, h41.pointCount());
 
         for (int i=0; i<h41.LegacyReturnCount; i++)
             EXPECT_EQ(h41.legacyPointsByReturn[i], h41.ePointsByReturn[i]);
@@ -2295,14 +2316,14 @@ TEST(LasWriterTest, issue2235)
 
         const las::Header& h46 = tester.header(writer46);
 
-        EXPECT_EQ(h46.legacyPointCount, 0);
-        EXPECT_NE(h46.pointCount(), 0);
+        EXPECT_EQ(h46.legacyPointCount, 0UL);
+        EXPECT_NE(h46.pointCount(), 0UL);
 
         for (int i=0; i<h46.LegacyReturnCount; i++)
         {
-            EXPECT_EQ(h46.legacyPointsByReturn[i], 0);
+            EXPECT_EQ(h46.legacyPointsByReturn[i], 0UL);
             if (i < returnsWithPoints)
-                EXPECT_NE(h46.ePointsByReturn[i], 0);
+                EXPECT_NE(h46.ePointsByReturn[i], 0UL);
         }
     }
 
@@ -2330,14 +2351,14 @@ TEST(LasWriterTest, issue2235)
 
         const las::Header& headerCopc = tester.header(readerCopc);
 
-        EXPECT_EQ(headerCopc.legacyPointCount, 0);
-        EXPECT_NE(headerCopc.pointCount(), 0);
+        EXPECT_EQ(headerCopc.legacyPointCount, 0UL);
+        EXPECT_NE(headerCopc.pointCount(), 0UL);
 
         for (int i=0; i<headerCopc.LegacyReturnCount; i++)
         {
-            EXPECT_EQ(headerCopc.legacyPointsByReturn[i], 0);
+            EXPECT_EQ(headerCopc.legacyPointsByReturn[i], 0UL);
             if (i < returnsWithPoints)
-                EXPECT_NE(headerCopc.ePointsByReturn[i], 0);
+                EXPECT_NE(headerCopc.ePointsByReturn[i], 0UL);
         }
     }
 }
